# In 2.6, compile does not fail when site.pp does not exist.
#
# However, if a catalog is compiled when site.pp does not exist, 
# puppetmaster does not detect when site.pp is created. This requires a restart
# 
 
test_name "Ticket 5477, Puppet Master does not detect newly created site.pp file"

# Kill running Puppet Master
step "Master: kill running Puppet Master"
on master, "ps -U puppet | awk '/puppet/ { print \$1 }' | xargs kill"

on master, "rm -f #{manifest_file}"
on hosts, "rm -rf /etc/puppet/ssl"

with_master_running_on(master, "--manifest #{manifest_file} --dns_alt_names=\"puppet, $(hostname -s), $(hostname -f)\" --verbose --filetimeout 1 --autosign true") do
  # Run test on Agents
  step "Agent: agent --test"
  on agents, puppet_agent("--test --server #{master}")

  # Create a new site.pp
  step "Master: create basic site.pp file"
  on master, "echo 'notify{ticket_5477_notify:}' > /etc/puppet/manifests/site.pp"

  sleep 20

  step "Agent: puppet agent --test"
  agents.each { |agent|
    on agent, "puppet agent -t", :acceptable_exit_codes => [2]
    fail_test "Site.pp not detect at Master?" unless
      stdout.include? 'ticket_5477_notify'
  }
end

step "Clean-up site.pp"
on master, "rm /etc/puppet/manifests/site.pp"
